@@ -11,24 +11,23 @@
 
 /* Include files */
 #include "rt_nonfinite.h"
-#include "CVfast.h"
 #include "MAVEfast.h"
 #include "rdivide.h"
-#include "CVfast_emxutil.h"
+#include "MAVEfast_emxutil.h"
 
 /* Function Definitions */
 void rdivide(const emxArray_real_T *x, const emxArray_real_T *y, emxArray_real_T
              *z)
 {
-  int i4;
+  int i5;
   int loop_ub;
-  i4 = z->size[0] * z->size[1];
+  i5 = z->size[0] * z->size[1];
   z->size[0] = x->size[0];
   z->size[1] = x->size[1];
-  emxEnsureCapacity((emxArray__common *)z, i4, (int)sizeof(double));
+  emxEnsureCapacity((emxArray__common *)z, i5, (int)sizeof(double));
   loop_ub = x->size[0] * x->size[1];
-  for (i4 = 0; i4 < loop_ub; i4++) {
-    z->data[i4] = x->data[i4] / y->data[i4];
+  for (i5 = 0; i5 < loop_ub; i5++) {
+    z->data[i5] = x->data[i5] / y->data[i5];
   }
 }
 
