@@ -11,10 +11,9 @@
 
 /* Include files */
 #include "rt_nonfinite.h"
-#include "CVfast.h"
 #include "MAVEfast.h"
 #include "sortIdx.h"
-#include "CVfast_emxutil.h"
+#include "MAVEfast_emxutil.h"
 
 /* Function Declarations */
 static void b_merge(emxArray_int32_T *idx, emxArray_real_T *x, int offset, int
@@ -49,7 +48,7 @@ static void b_merge(emxArray_int32_T *idx, emxArray_real_T *x, int offset, int
     do {
       exitg1 = 0;
       iout++;
-      if (xwork->data[p] >= xwork->data[n]) {
+      if (xwork->data[p] <= xwork->data[n]) {
         idx->data[iout] = iwork->data[p];
         x->data[iout] = xwork->data[p];
         if (p + 1 < np) {
@@ -133,7 +132,7 @@ static void merge(emxArray_int32_T *idx, emxArray_real_T *x, int offset, int np,
     do {
       exitg1 = 0;
       iout++;
-      if (xwork->data[p] <= xwork->data[n]) {
+      if (xwork->data[p] >= xwork->data[n]) {
         idx->data[iout] = iwork->data[p];
         x->data[iout] = xwork->data[p];
         if (p + 1 < np) {
@@ -214,7 +213,6 @@ void b_sortIdx(emxArray_real_T *x, emxArray_int32_T *idx)
   int nBlocks;
   int b_iwork[256];
   double b_xwork[256];
-  int bLen;
   int bLen2;
   int nPairs;
   int exitg1;
@@ -241,315 +239,7 @@ void b_sortIdx(emxArray_real_T *x, emxArray_int32_T *idx)
     idx4[i] = 0;
   }
 
-  emxInit_int32_T(&iwork, 1);
-  wOffset = iwork->size[0];
-  iwork->size[0] = ib;
-  emxEnsureCapacity((emxArray__common *)iwork, wOffset, (int)sizeof(int));
-  i = iwork->size[0];
-  wOffset = iwork->size[0];
-  iwork->size[0] = i;
-  emxEnsureCapacity((emxArray__common *)iwork, wOffset, (int)sizeof(int));
-  for (wOffset = 0; wOffset < i; wOffset++) {
-    iwork->data[wOffset] = 0;
-  }
-
-  emxInit_real_T1(&xwork, 1);
-  i = x->size[0];
-  wOffset = xwork->size[0];
-  xwork->size[0] = i;
-  emxEnsureCapacity((emxArray__common *)xwork, wOffset, (int)sizeof(double));
-  i = xwork->size[0];
-  wOffset = xwork->size[0];
-  xwork->size[0] = i;
-  emxEnsureCapacity((emxArray__common *)xwork, wOffset, (int)sizeof(double));
-  for (wOffset = 0; wOffset < i; wOffset++) {
-    xwork->data[wOffset] = 0.0;
-  }
-
-  nNaNs = 0;
-  ib = 0;
-  for (k = 0; k + 1 <= n; k++) {
-    if (rtIsNaN(b_x->data[k])) {
-      idx->data[(n - nNaNs) - 1] = k + 1;
-      xwork->data[(n - nNaNs) - 1] = b_x->data[k];
-      nNaNs++;
-    } else {
-      ib++;
-      idx4[ib - 1] = k + 1;
-      x4[ib - 1] = b_x->data[k];
-      if (ib == 4) {
-        i = k - nNaNs;
-        if (x4[0] >= x4[1]) {
-          ib = 1;
-          wOffset = 2;
-        } else {
-          ib = 2;
-          wOffset = 1;
-        }
-
-        if (x4[2] >= x4[3]) {
-          i3 = 3;
-          i4 = 4;
-        } else {
-          i3 = 4;
-          i4 = 3;
-        }
-
-        if (x4[ib - 1] >= x4[i3 - 1]) {
-          if (x4[wOffset - 1] >= x4[i3 - 1]) {
-            perm[0] = (signed char)ib;
-            perm[1] = (signed char)wOffset;
-            perm[2] = (signed char)i3;
-            perm[3] = (signed char)i4;
-          } else if (x4[wOffset - 1] >= x4[i4 - 1]) {
-            perm[0] = (signed char)ib;
-            perm[1] = (signed char)i3;
-            perm[2] = (signed char)wOffset;
-            perm[3] = (signed char)i4;
-          } else {
-            perm[0] = (signed char)ib;
-            perm[1] = (signed char)i3;
-            perm[2] = (signed char)i4;
-            perm[3] = (signed char)wOffset;
-          }
-        } else if (x4[ib - 1] >= x4[i4 - 1]) {
-          if (x4[wOffset - 1] >= x4[i4 - 1]) {
-            perm[0] = (signed char)i3;
-            perm[1] = (signed char)ib;
-            perm[2] = (signed char)wOffset;
-            perm[3] = (signed char)i4;
-          } else {
-            perm[0] = (signed char)i3;
-            perm[1] = (signed char)ib;
-            perm[2] = (signed char)i4;
-            perm[3] = (signed char)wOffset;
-          }
-        } else {
-          perm[0] = (signed char)i3;
-          perm[1] = (signed char)i4;
-          perm[2] = (signed char)ib;
-          perm[3] = (signed char)wOffset;
-        }
-
-        idx->data[i - 3] = idx4[perm[0] - 1];
-        idx->data[i - 2] = idx4[perm[1] - 1];
-        idx->data[i - 1] = idx4[perm[2] - 1];
-        idx->data[i] = idx4[perm[3] - 1];
-        b_x->data[i - 3] = x4[perm[0] - 1];
-        b_x->data[i - 2] = x4[perm[1] - 1];
-        b_x->data[i - 1] = x4[perm[2] - 1];
-        b_x->data[i] = x4[perm[3] - 1];
-        ib = 0;
-      }
-    }
-  }
-
-  wOffset = (x->size[0] - nNaNs) - 1;
-  if (ib > 0) {
-    for (i = 0; i < 4; i++) {
-      perm[i] = 0;
-    }
-
-    if (ib == 1) {
-      perm[0] = 1;
-    } else if (ib == 2) {
-      if (x4[0] >= x4[1]) {
-        perm[0] = 1;
-        perm[1] = 2;
-      } else {
-        perm[0] = 2;
-        perm[1] = 1;
-      }
-    } else if (x4[0] >= x4[1]) {
-      if (x4[1] >= x4[2]) {
-        perm[0] = 1;
-        perm[1] = 2;
-        perm[2] = 3;
-      } else if (x4[0] >= x4[2]) {
-        perm[0] = 1;
-        perm[1] = 3;
-        perm[2] = 2;
-      } else {
-        perm[0] = 3;
-        perm[1] = 1;
-        perm[2] = 2;
-      }
-    } else if (x4[0] >= x4[2]) {
-      perm[0] = 2;
-      perm[1] = 1;
-      perm[2] = 3;
-    } else if (x4[1] >= x4[2]) {
-      perm[0] = 2;
-      perm[1] = 3;
-      perm[2] = 1;
-    } else {
-      perm[0] = 3;
-      perm[1] = 2;
-      perm[2] = 1;
-    }
-
-    for (k = 1; k <= ib; k++) {
-      idx->data[(wOffset - ib) + k] = idx4[perm[k - 1] - 1];
-      b_x->data[(wOffset - ib) + k] = x4[perm[k - 1] - 1];
-    }
-  }
-
-  i = nNaNs >> 1;
-  for (k = 1; k <= i; k++) {
-    ib = idx->data[wOffset + k];
-    idx->data[wOffset + k] = idx->data[n - k];
-    idx->data[n - k] = ib;
-    b_x->data[wOffset + k] = xwork->data[n - k];
-    b_x->data[n - k] = xwork->data[wOffset + k];
-  }
-
-  if ((nNaNs & 1) != 0) {
-    b_x->data[(wOffset + i) + 1] = xwork->data[(wOffset + i) + 1];
-  }
-
-  nNonNaN = x->size[0] - nNaNs;
-  i = 2;
-  if (nNonNaN > 1) {
-    if (x->size[0] >= 256) {
-      nBlocks = nNonNaN >> 8;
-      if (nBlocks > 0) {
-        for (i3 = 1; i3 <= nBlocks; i3++) {
-          i4 = ((i3 - 1) << 8) - 1;
-          for (n = 0; n < 6; n++) {
-            bLen = 1 << (n + 2);
-            bLen2 = bLen << 1;
-            nPairs = 256 >> (n + 3);
-            for (k = 1; k <= nPairs; k++) {
-              ib = i4 + (k - 1) * bLen2;
-              for (i = 1; i <= bLen2; i++) {
-                b_iwork[i - 1] = idx->data[ib + i];
-                b_xwork[i - 1] = b_x->data[ib + i];
-              }
-
-              wOffset = 0;
-              i = bLen;
-              do {
-                exitg1 = 0;
-                ib++;
-                if (b_xwork[wOffset] >= b_xwork[i]) {
-                  idx->data[ib] = b_iwork[wOffset];
-                  b_x->data[ib] = b_xwork[wOffset];
-                  if (wOffset + 1 < bLen) {
-                    wOffset++;
-                  } else {
-                    exitg1 = 1;
-                  }
-                } else {
-                  idx->data[ib] = b_iwork[i];
-                  b_x->data[ib] = b_xwork[i];
-                  if (i + 1 < bLen2) {
-                    i++;
-                  } else {
-                    i = ib - wOffset;
-                    while (wOffset + 1 <= bLen) {
-                      idx->data[(i + wOffset) + 1] = b_iwork[wOffset];
-                      b_x->data[(i + wOffset) + 1] = b_xwork[wOffset];
-                      wOffset++;
-                    }
-
-                    exitg1 = 1;
-                  }
-                }
-              } while (exitg1 == 0);
-            }
-          }
-        }
-
-        i = nBlocks << 8;
-        ib = nNonNaN - i;
-        if (ib > 0) {
-          b_merge_block(idx, b_x, i, ib, 2, iwork, xwork);
-        }
-
-        i = 8;
-      }
-    }
-
-    b_merge_block(idx, b_x, 0, nNonNaN, i, iwork, xwork);
-  }
-
-  if ((nNaNs > 0) && (nNonNaN > 0)) {
-    for (k = 0; k + 1 <= nNaNs; k++) {
-      xwork->data[k] = b_x->data[nNonNaN + k];
-      iwork->data[k] = idx->data[nNonNaN + k];
-    }
-
-    for (k = nNonNaN - 1; k + 1 > 0; k--) {
-      b_x->data[nNaNs + k] = b_x->data[k];
-      idx->data[nNaNs + k] = idx->data[k];
-    }
-
-    for (k = 0; k + 1 <= nNaNs; k++) {
-      b_x->data[k] = xwork->data[k];
-      idx->data[k] = iwork->data[k];
-    }
-  }
-
-  emxFree_real_T(&xwork);
-  emxFree_int32_T(&iwork);
-  wOffset = x->size[0];
-  x->size[0] = b_x->size[0];
-  emxEnsureCapacity((emxArray__common *)x, wOffset, (int)sizeof(double));
-  i = b_x->size[0];
-  for (wOffset = 0; wOffset < i; wOffset++) {
-    x->data[wOffset] = b_x->data[wOffset];
-  }
-
-  emxFree_real_T(&b_x);
-}
-
-void sortIdx(emxArray_real_T *x, emxArray_int32_T *idx)
-{
-  emxArray_real_T *b_x;
-  int ib;
-  int wOffset;
-  int i;
-  int n;
-  double x4[4];
-  int idx4[4];
-  emxArray_int32_T *iwork;
-  emxArray_real_T *xwork;
-  int nNaNs;
-  int k;
-  signed char perm[4];
-  int nNonNaN;
-  int i3;
-  int i4;
-  int nBlocks;
-  int b_iwork[256];
-  double b_xwork[256];
-  int bLen2;
-  int nPairs;
-  int exitg1;
-  emxInit_real_T1(&b_x, 1);
-  ib = x->size[0];
-  wOffset = b_x->size[0];
-  b_x->size[0] = x->size[0];
-  emxEnsureCapacity((emxArray__common *)b_x, wOffset, (int)sizeof(double));
-  i = x->size[0];
-  for (wOffset = 0; wOffset < i; wOffset++) {
-    b_x->data[wOffset] = x->data[wOffset];
-  }
-
-  wOffset = idx->size[0];
-  idx->size[0] = ib;
-  emxEnsureCapacity((emxArray__common *)idx, wOffset, (int)sizeof(int));
-  for (wOffset = 0; wOffset < ib; wOffset++) {
-    idx->data[wOffset] = 0;
-  }
-
-  n = x->size[0];
-  for (i = 0; i < 4; i++) {
-    x4[i] = 0.0;
-    idx4[i] = 0;
-  }
-
-  emxInit_int32_T(&iwork, 1);
+  emxInit_int32_T1(&iwork, 1);
   wOffset = iwork->size[0];
   iwork->size[0] = ib;
   emxEnsureCapacity((emxArray__common *)iwork, wOffset, (int)sizeof(int));
@@ -768,6 +458,298 @@ void sortIdx(emxArray_real_T *x, emxArray_int32_T *idx)
           }
         }
 
+        i = nBlocks << 8;
+        ib = nNonNaN - i;
+        if (ib > 0) {
+          b_merge_block(idx, b_x, i, ib, 2, iwork, xwork);
+        }
+
+        i = 8;
+      }
+    }
+
+    b_merge_block(idx, b_x, 0, nNonNaN, i, iwork, xwork);
+  }
+
+  emxFree_real_T(&xwork);
+  emxFree_int32_T(&iwork);
+  wOffset = x->size[0];
+  x->size[0] = b_x->size[0];
+  emxEnsureCapacity((emxArray__common *)x, wOffset, (int)sizeof(double));
+  i = b_x->size[0];
+  for (wOffset = 0; wOffset < i; wOffset++) {
+    x->data[wOffset] = b_x->data[wOffset];
+  }
+
+  emxFree_real_T(&b_x);
+}
+
+void sortIdx(emxArray_real_T *x, emxArray_int32_T *idx)
+{
+  emxArray_real_T *b_x;
+  int ib;
+  int wOffset;
+  int i;
+  int n;
+  double x4[4];
+  int idx4[4];
+  emxArray_int32_T *iwork;
+  emxArray_real_T *xwork;
+  int nNaNs;
+  int k;
+  signed char perm[4];
+  int nNonNaN;
+  int i3;
+  int i4;
+  int nBlocks;
+  int b_iwork[256];
+  double b_xwork[256];
+  int bLen;
+  int bLen2;
+  int nPairs;
+  int exitg1;
+  emxInit_real_T1(&b_x, 1);
+  ib = x->size[0];
+  wOffset = b_x->size[0];
+  b_x->size[0] = x->size[0];
+  emxEnsureCapacity((emxArray__common *)b_x, wOffset, (int)sizeof(double));
+  i = x->size[0];
+  for (wOffset = 0; wOffset < i; wOffset++) {
+    b_x->data[wOffset] = x->data[wOffset];
+  }
+
+  wOffset = idx->size[0];
+  idx->size[0] = ib;
+  emxEnsureCapacity((emxArray__common *)idx, wOffset, (int)sizeof(int));
+  for (wOffset = 0; wOffset < ib; wOffset++) {
+    idx->data[wOffset] = 0;
+  }
+
+  n = x->size[0];
+  for (i = 0; i < 4; i++) {
+    x4[i] = 0.0;
+    idx4[i] = 0;
+  }
+
+  emxInit_int32_T1(&iwork, 1);
+  wOffset = iwork->size[0];
+  iwork->size[0] = ib;
+  emxEnsureCapacity((emxArray__common *)iwork, wOffset, (int)sizeof(int));
+  i = iwork->size[0];
+  wOffset = iwork->size[0];
+  iwork->size[0] = i;
+  emxEnsureCapacity((emxArray__common *)iwork, wOffset, (int)sizeof(int));
+  for (wOffset = 0; wOffset < i; wOffset++) {
+    iwork->data[wOffset] = 0;
+  }
+
+  emxInit_real_T1(&xwork, 1);
+  i = x->size[0];
+  wOffset = xwork->size[0];
+  xwork->size[0] = i;
+  emxEnsureCapacity((emxArray__common *)xwork, wOffset, (int)sizeof(double));
+  i = xwork->size[0];
+  wOffset = xwork->size[0];
+  xwork->size[0] = i;
+  emxEnsureCapacity((emxArray__common *)xwork, wOffset, (int)sizeof(double));
+  for (wOffset = 0; wOffset < i; wOffset++) {
+    xwork->data[wOffset] = 0.0;
+  }
+
+  nNaNs = 0;
+  ib = 0;
+  for (k = 0; k + 1 <= n; k++) {
+    if (rtIsNaN(b_x->data[k])) {
+      idx->data[(n - nNaNs) - 1] = k + 1;
+      xwork->data[(n - nNaNs) - 1] = b_x->data[k];
+      nNaNs++;
+    } else {
+      ib++;
+      idx4[ib - 1] = k + 1;
+      x4[ib - 1] = b_x->data[k];
+      if (ib == 4) {
+        i = k - nNaNs;
+        if (x4[0] >= x4[1]) {
+          ib = 1;
+          wOffset = 2;
+        } else {
+          ib = 2;
+          wOffset = 1;
+        }
+
+        if (x4[2] >= x4[3]) {
+          i3 = 3;
+          i4 = 4;
+        } else {
+          i3 = 4;
+          i4 = 3;
+        }
+
+        if (x4[ib - 1] >= x4[i3 - 1]) {
+          if (x4[wOffset - 1] >= x4[i3 - 1]) {
+            perm[0] = (signed char)ib;
+            perm[1] = (signed char)wOffset;
+            perm[2] = (signed char)i3;
+            perm[3] = (signed char)i4;
+          } else if (x4[wOffset - 1] >= x4[i4 - 1]) {
+            perm[0] = (signed char)ib;
+            perm[1] = (signed char)i3;
+            perm[2] = (signed char)wOffset;
+            perm[3] = (signed char)i4;
+          } else {
+            perm[0] = (signed char)ib;
+            perm[1] = (signed char)i3;
+            perm[2] = (signed char)i4;
+            perm[3] = (signed char)wOffset;
+          }
+        } else if (x4[ib - 1] >= x4[i4 - 1]) {
+          if (x4[wOffset - 1] >= x4[i4 - 1]) {
+            perm[0] = (signed char)i3;
+            perm[1] = (signed char)ib;
+            perm[2] = (signed char)wOffset;
+            perm[3] = (signed char)i4;
+          } else {
+            perm[0] = (signed char)i3;
+            perm[1] = (signed char)ib;
+            perm[2] = (signed char)i4;
+            perm[3] = (signed char)wOffset;
+          }
+        } else {
+          perm[0] = (signed char)i3;
+          perm[1] = (signed char)i4;
+          perm[2] = (signed char)ib;
+          perm[3] = (signed char)wOffset;
+        }
+
+        idx->data[i - 3] = idx4[perm[0] - 1];
+        idx->data[i - 2] = idx4[perm[1] - 1];
+        idx->data[i - 1] = idx4[perm[2] - 1];
+        idx->data[i] = idx4[perm[3] - 1];
+        b_x->data[i - 3] = x4[perm[0] - 1];
+        b_x->data[i - 2] = x4[perm[1] - 1];
+        b_x->data[i - 1] = x4[perm[2] - 1];
+        b_x->data[i] = x4[perm[3] - 1];
+        ib = 0;
+      }
+    }
+  }
+
+  wOffset = (x->size[0] - nNaNs) - 1;
+  if (ib > 0) {
+    for (i = 0; i < 4; i++) {
+      perm[i] = 0;
+    }
+
+    if (ib == 1) {
+      perm[0] = 1;
+    } else if (ib == 2) {
+      if (x4[0] >= x4[1]) {
+        perm[0] = 1;
+        perm[1] = 2;
+      } else {
+        perm[0] = 2;
+        perm[1] = 1;
+      }
+    } else if (x4[0] >= x4[1]) {
+      if (x4[1] >= x4[2]) {
+        perm[0] = 1;
+        perm[1] = 2;
+        perm[2] = 3;
+      } else if (x4[0] >= x4[2]) {
+        perm[0] = 1;
+        perm[1] = 3;
+        perm[2] = 2;
+      } else {
+        perm[0] = 3;
+        perm[1] = 1;
+        perm[2] = 2;
+      }
+    } else if (x4[0] >= x4[2]) {
+      perm[0] = 2;
+      perm[1] = 1;
+      perm[2] = 3;
+    } else if (x4[1] >= x4[2]) {
+      perm[0] = 2;
+      perm[1] = 3;
+      perm[2] = 1;
+    } else {
+      perm[0] = 3;
+      perm[1] = 2;
+      perm[2] = 1;
+    }
+
+    for (k = 1; k <= ib; k++) {
+      idx->data[(wOffset - ib) + k] = idx4[perm[k - 1] - 1];
+      b_x->data[(wOffset - ib) + k] = x4[perm[k - 1] - 1];
+    }
+  }
+
+  i = nNaNs >> 1;
+  for (k = 1; k <= i; k++) {
+    ib = idx->data[wOffset + k];
+    idx->data[wOffset + k] = idx->data[n - k];
+    idx->data[n - k] = ib;
+    b_x->data[wOffset + k] = xwork->data[n - k];
+    b_x->data[n - k] = xwork->data[wOffset + k];
+  }
+
+  if ((nNaNs & 1) != 0) {
+    b_x->data[(wOffset + i) + 1] = xwork->data[(wOffset + i) + 1];
+  }
+
+  nNonNaN = x->size[0] - nNaNs;
+  i = 2;
+  if (nNonNaN > 1) {
+    if (x->size[0] >= 256) {
+      nBlocks = nNonNaN >> 8;
+      if (nBlocks > 0) {
+        for (i3 = 1; i3 <= nBlocks; i3++) {
+          i4 = ((i3 - 1) << 8) - 1;
+          for (n = 0; n < 6; n++) {
+            bLen = 1 << (n + 2);
+            bLen2 = bLen << 1;
+            nPairs = 256 >> (n + 3);
+            for (k = 1; k <= nPairs; k++) {
+              ib = i4 + (k - 1) * bLen2;
+              for (i = 1; i <= bLen2; i++) {
+                b_iwork[i - 1] = idx->data[ib + i];
+                b_xwork[i - 1] = b_x->data[ib + i];
+              }
+
+              wOffset = 0;
+              i = bLen;
+              do {
+                exitg1 = 0;
+                ib++;
+                if (b_xwork[wOffset] >= b_xwork[i]) {
+                  idx->data[ib] = b_iwork[wOffset];
+                  b_x->data[ib] = b_xwork[wOffset];
+                  if (wOffset + 1 < bLen) {
+                    wOffset++;
+                  } else {
+                    exitg1 = 1;
+                  }
+                } else {
+                  idx->data[ib] = b_iwork[i];
+                  b_x->data[ib] = b_xwork[i];
+                  if (i + 1 < bLen2) {
+                    i++;
+                  } else {
+                    i = ib - wOffset;
+                    while (wOffset + 1 <= bLen) {
+                      idx->data[(i + wOffset) + 1] = b_iwork[wOffset];
+                      b_x->data[(i + wOffset) + 1] = b_xwork[wOffset];
+                      wOffset++;
+                    }
+
+                    exitg1 = 1;
+                  }
+                }
+              } while (exitg1 == 0);
+            }
+          }
+        }
+
         i = nBlocks << 8;
         ib = nNonNaN - i;
         if (ib > 0) {
@@ -781,6 +763,23 @@ void sortIdx(emxArray_real_T *x, emxArray_int32_T *idx)
     merge_block(idx, b_x, 0, nNonNaN, i, iwork, xwork);
   }
 
+  if ((nNaNs > 0) && (nNonNaN > 0)) {
+    for (k = 0; k + 1 <= nNaNs; k++) {
+      xwork->data[k] = b_x->data[nNonNaN + k];
+      iwork->data[k] = idx->data[nNonNaN + k];
+    }
+
+    for (k = nNonNaN - 1; k + 1 > 0; k--) {
+      b_x->data[nNaNs + k] = b_x->data[k];
+      idx->data[nNaNs + k] = idx->data[k];
+    }
+
+    for (k = 0; k + 1 <= nNaNs; k++) {
+      b_x->data[k] = xwork->data[k];
+      idx->data[k] = iwork->data[k];
+    }
+  }
+
   emxFree_real_T(&xwork);
   emxFree_int32_T(&iwork);
   wOffset = x->size[0];
