@@ -18,15 +18,14 @@
 #include <stddef.h>
 #include <stdlib.h>
 #include <string.h>
-#include "rt_defines.h"
 #include "rt_nonfinite.h"
 #include "rtwtypes.h"
 //#include "omp.h"
-#include "CVfast_types.h"
+#include "MAVEfast_types.h"
 
 /* Function Declarations */
-extern double b_sum(const emxArray_real_T *x);
-extern void sum(const emxArray_real_T *x, emxArray_real_T *y);
+extern void b_sum(const emxArray_real_T *x, emxArray_real_T *y);
+extern double sum(const emxArray_real_T *x);
 
 #endif
 
